@@ -2,6 +2,7 @@ from .SURE import SURE
 from .DensityFlow import DensityFlow
 from .PerturbE import PerturbE
 from .TranscriptomeDecoder import TranscriptomeDecoder
+from .SimpleTranscriptomeDecoder import SimpleTranscriptomeDecoder
 
 from . import utils 
 from . import codebook
@@ -12,5 +13,6 @@ from . import flow
 from . import perturb
 from . import PerturbE
 from . import TranscriptomeDecoder
+from . import SimpleTranscriptomeDecoder
 
-__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'TranscriptomeDecoder', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
+__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'TranscriptomeDecoder', 'SimpleTranscriptomeDecoder', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
