@@ -41,6 +41,18 @@ class VectorFieldEval:
         divergence[np.isnan(divergence)] = 0
         
         return divergence
+    
+    def movement_stats(self,vectors):
+        return calculate_movement_stats(vectors)
+    
+    def direction_stats(self, vectors):
+        return calculate_direction_stats(vectors)
+    
+    def movement_energy(self, vectors, masses=None):
+        return calculate_movement_energy(vectors, masses)
+    
+    def movement_divergence(self, positions, vectors):
+        return calculate_movement_divergence(positions, vectors)
 
         
 def calculate_movement_stats(vectors):
